@@ -16,13 +16,15 @@ def fetch_relational_data(
         query_type=None,
         search_list=None,
         append_extra=None,
+        use_country_code=None,
 
 ):
     # app = WeDeliverCore.get_app()
     # db = app.extensions['sqlalchemy'].db
 
     if query_type == QueryTypes.SEARCH.value:
-        result, validation = search_function(table_name=table_name, search_list=search_list, append_extra=append_extra)
+        result, validation = search_function(table_name=table_name, search_list=search_list, append_extra=append_extra,
+                                             use_country_code=use_country_code)
         return dict(
             result=result,
             validation=validation
@@ -40,7 +42,7 @@ def fetch_relational_data(
                 table_name=table_name,
                 column_name=column_name,
                 compair_operator=compair_operator,
-                column_values="({})".format(
+                column_values="('{}')".format(
                     "', '".join([str(val) for val in column_values])) if compair_operator == 'IN' else column_values,
             )
             relational_data_result = sql(query)
